DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'testproject/test.db3'
    }
}
INSTALLED_APPS = [
    'django.contrib.contenttypes',
    'picklefield',
]
SITE_ID = 1
ROOT_URLCONF = 'testproject.urls'
SECRET_KEY = '1'
